@@ -6,7 +6,7 @@
 
 __copyright__ = 'this file is in the public domain'
 
-__version__ = "0.9.1.3"
+__version__ = "0.9.2"
 
 __all__ = ['aliases', 'database', 'ignore', 'periodical', 'tests', \
 'botbase',  'datadir', 'persist', 'threads', \
@@ -15,7 +15,7 @@ __all__ = ['aliases', 'database', 'ignore', 'periodical', 'tests', \
 'channels', 'examples', 'jsonusers', 'plugs', 'wait', \
 'commands', 'exit', 'less', 'redispatcher', \
 'compat', 'fleet', 'monitor', 'rest', \
-'config', 'morphs', 'runner', \
+'config', 'morphs', 'runner', 'wave', \
 'contrib', 'gozerimport', 'partyline', 'stats', 'utils', 'reboot', 'xmpp']
 
 # ==============
