@@ -214,7 +214,7 @@ class Callbacks(object):
                 stats.up('callbacks', 'ALL')
                 self.callback(cb, bot, ievent)
 
-        cmnd = ievent.cmnd.upper()
+        cmnd = ievent.cbtype or ievent.cmnd.upper()
 
         # check for CMND callbacks
         if self.cbs.has_key(cmnd):
@@ -254,6 +254,8 @@ class Callbacks(object):
             stats.up('callbacks', getname(cb.func))
             stats.up('callbacks', cb.plugname)
 
+            ievent.iscallback = True
+
             # launcn the callback .. either threaded or dispatched at runners
             if cb.threaded:
                 start_new_thread(cb.func, (bot, ievent), cb.kwargs)
@@ -267,5 +269,6 @@ class Callbacks(object):
 
 # callbacks object is the same for ICR and Jabber
 callbacks = jcallbacks = Callbacks()
+gn_callbacks = Callbacks()
 
 # END INIT
