@@ -82,7 +82,7 @@ class Command(object):
         self.threaded = copy.deepcopy(threaded) # set if threaded exec is required
         self.allowqueue = copy.deepcopy(allowqueue) # set if command is allowed to be used in pipeline
         self.options = dict(options) # options set in the command 
-        self.activate = False
+        self.activate = True
         
 class Commands(dict):
 
@@ -251,11 +251,11 @@ class Commands(dict):
         # overload the command with given permissions
         for com in self.values():
             try:
-                if com.func.func_name == funcname:
+                if com.func.func_name == name:
                     com.perms = perms
                     return True
             except AttributeError:
-                rlog(10, 'commands', "permoverload: no %s function" % funcname)
+                rlog(10, 'commands', "permoverload: no %s function" % name)
         return False
 
     #@locked
@@ -564,7 +564,7 @@ class Botcommands(Commands):
         # execute command
         if com.threaded or ievent.threaded:
             thread = start_bot_command(com.func, (bot, ievent))
-            if wait:
+            if thread and wait:
                 thread.join()
         else:	
             speed = ievent.speed or com.speed
