@@ -15,8 +15,10 @@ __copyright__ = 'this file is in the public domain'
 
 # gozerbot imports
 from utils.exception import handle_exception
+from utils.log import rlog
 
 # simplejson imports
+
 from simplejson import loads, dumps
 
 # basic imports
@@ -39,23 +41,25 @@ class Config(dict):
       
     """
 
-    def __init__(self, ddir=None, filename=None, inittxt=None, *args, **kw):
+    def __init__(self, ddir=None, filename=None, inittxt=None, verbose=False, *args, **kw):
         dict.__init__(self, *args, **kw)
+        self.jsondb = None
         self.dir = ddir or 'gozerdata'
         self.filename = filename or 'config'
         self.cfile = self.dir + os.sep + self.filename
 
-        #  check if provided dir exists if not create it
-        if not os.path.exists(self.dir):
-            os.mkdir(self.dir)
+        if hasattr(os, 'mkdir'):
+            #  check if provided dir exists if not create it
+            if not os.path.exists(self.dir):
+                os.mkdir(self.dir)
 
-        # see if initial data has to be written
-        if inittxt and not os.path.exists(self.cfile):
-            self.write_init(inittxt)
+            # see if initial data has to be written
+            if inittxt and not os.path.exists(self.cfile):
+                self.write_init(inittxt)
 
         self.configlist = []
         self.lock = thread.allocate_lock()
-        self.load()
+        self.load(verbose)
 
     def __getitem__(self, item):
         if not self.has_key(item):
@@ -67,7 +71,7 @@ class Config(dict):
         dict.__setitem__(self, item, value)
         self.save()
 
-    def load(self):
+    def load(self, verbose=False):
 
         """
             load the config file.
@@ -80,10 +84,51 @@ class Config(dict):
         self.reload()
 
         if self.filename == 'mainconfig':
+            self.setdefault('owner', [])
+            self.setdefault('loglevel', 10)
+            self.setdefault('loglist',  [])
+            self.setdefault('resource', 'gozerbot')
+            self.setdefault('quitmsg', "http://gozerbot.googlecode.com")
+            self.setdefault('mask', "700")
+            self.setdefault('debug', 0)
+            self.setdefault('nodb', 0)
+            self.setdefault('plugdeny', [])
+
+            #self.setdefault('jsonuser', "users.json")
+            self.setdefault('loadlist', ["alias", "all", "at", "chanperm", "choice", "code", "core", "count", "fleet", "googletalk", "grep", "ignore", "irc", "jabber", "job", "misc", "nickcapture", "nickserv", "not", "quote", "reload", "rest", "reverse", "size", "sort", "tail", "tell", "to", "underauth", "uniq", "user", "userstate", "stats", "throttle"])
+            self.setdefault('dotchars',  " .. ")
+            self.setdefault('floodallow', 1)
+            self.setdefault('auto_register', 0)
             import gozerbot
-            self['version'] = "GOZERBOT %s RELEASE" % gozerbot.__version__
-            if not self['loadlist']:
-                self['loadlist'] = ["alias", "all", "at", "chanperm", "choice", "code", "core", "count", "fleet", "googletalk", "grep", "ignore", "irc", "jabber", "job", "misc", "nickcapture", "nickserv", "not", "quote", "reload", "rest", "reverse", "size", "sort", "tail", "tell", "to", "underauth", "uniq", "user", "userstate", "stats"]
+            self['version'] = "GOZERBOT %s " % gozerbot.__version__
+            self['version'] += "BETA1"
+
+        elif 'fleet' in self.dir:
+            self.setdefault("enable", 1)
+            self.setdefault("type", "irc")
+            self.setdefault("owner", [])
+            self.setdefault("user", "")
+            self.setdefault("nick", "gozerbot")
+            self.setdefault("server", "")
+            self.setdefault("host", "")
+            self.setdefault("password", "")
+            self.setdefault("port", 0)
+            self.setdefault("ssl", 0)
+            self.setdefault("ipv6", 0)
+            self.setdefault("username", "gozerbot")
+            self.setdefault("realname", "GOZERBOT")
+            self.setdefault("defaultcc", "!")
+            self.setdefault("quitmsg", "http://gozerbot.googlecode.com")
+            self.setdefault("bindhost", "")
+            self.setdefault("nolimiter", 0)
+            self.setdefault("nickservpass", "")
+            self.setdefault("nickservtxt", ["set unfiltered on", ])
+            self.setdefault("auto_register", 0)
+            self.setdefault("stripident", 0)   
+            self.setdefault("loadlist", [])    
+
+        if verbose:
+            rlog(10, 'config', str(self))
 
     def save(self):
 
@@ -217,16 +262,16 @@ class Config(dict):
 
 
         """
+        if hasattr(os, 'mkdir'):
+            # check if datadir is there .. if not create it
+            if not os.path.isdir(self.dir):
+                os.mkdir(self.dir)
 
-        # check if datadir is there .. if not create it
-        if not os.path.isdir(self.dir):
-            os.mkdir(self.dir)
-
-        # check if config file is already there .. if not init it 
-        if not os.path.isfile(self.cfile):
-            cfgfile = open(self.cfile, 'w')
-            cfgfile.write(txt)
-            cfgfile.close()
+            # check if config file is already there .. if not init it 
+            if not os.path.isfile(self.cfile):
+                cfgfile = open(self.cfile, 'w')
+                cfgfile.write(txt)
+                cfgfile.close()
 
 
 mainconfigtxt = """# gozerbot config
@@ -246,7 +291,7 @@ loglevel = 10
 loglist = []
 
 # quit message
-quitmsg = "http://gozerbot.org"
+quitmsg = "http://gozerbot.googlecode.com"
 
 # botterdata dir mask
 mask = "700"
@@ -268,11 +313,22 @@ dbpasswd = "mekker2"
 #jsonuser = "users.json"
 
 # loadlist
-loadlist = ["alias", "all", "at", "chanperm", "choice", "code", "core", "count", "fleet", "googletalk", "grep", "ignore", "irc", "jabber", "job", "misc", "nickcapture", "nickserv", "not", "quote", "reload", "rest", "reverse", "size", "sort", "tail", "tell", "to", "underauth", "uniq", "user", "userstate", "plug", "test"]
+loadlist = ["alias", "all", "at", "chanperm", "choice", "code", "core", "count", "fleet", "googletalk", "grep", "ignore", "irc", "jabber", "job", "misc", "nickcapture", "nickserv", "not", "quote", "reload", "rest", "reverse", "size", "sort", "tail", "tell", "to", "underauth", "uniq", "user", "userstate", "plug", "test", "stats", "inform", "admin", "throttle", "mysqlkeepalive", "gozernet"]
 
 # chars used to seperate result
 dotchars = " .. "
 
+# nr of lines before flood protect kicks in
+
+floodallow = 2
+
+# auto register new users 
+
+auto_register = 0
+
+# resource used by xmpp bot (global)
+resource = "gozerbot"
+
 """
 
 
@@ -298,16 +354,16 @@ owner = []
 ## CONNECTION STUFF
 
 # user (jabber) .. needs to be full JID because server is taken from it
-user = "botter@gozerbot.org"
+user = "botter@jsonbot.org"
 
 # nick (irc)
 nick = "gozerbot"
 
 # server (irc)
-server = "localhost"
+server = ""
 
 # host (jabber) .. server to connect to
-host = "gozerbot.org"
+host = ""
 
 # password (irc and jabber)
 password = ""
@@ -333,7 +389,7 @@ realname = "GOZERBOT"
 defaultcc = "!"
 
 # quit message
-quitmsg = "http://gozerbot.org"
+quitmsg = "http://gozerbot.googlecode.com"
 
 # bindhost .. uncomment to enable
 bindhost = ""
