@@ -249,10 +249,12 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         if Irc.reconnect(self):
             self.joinchannels()
 
-    def joinchannels(self):
+    def joinchannels(self, wait=0):
 
         """ join channels. """
-
+        wait = wait or self.cfg['sleepbeforejoin'] or 5
+        rlog(10, self.name, "waiting %s seconds before joining channels" % wait)
+        time.sleep(wait)
         for i in self.state['joinedchannels']:
             try:
                 key = self.channels.getkey(i)
@@ -347,7 +349,7 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         self.getchannelmode(channel)
         return 1
 
-    def say(self, printto, what, who=None, how='msg', fromm=None, speed=5):
+    def say(self, printto, what, who=None, how='msg', fromm=None, speed=5, groupchat=False):
 
         """ output what to printto. """
 
@@ -363,7 +365,7 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
             pass
         if notice:
             how = 'notice'
-        Irc.say(self, printto, what, who, how, fromm, speed)
+        Irc.say(self, printto, what, who, how, fromm, speed, groupchat)
 
     def handle_privmsg(self, ievent):
 
@@ -393,10 +395,10 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         # set bot and socket in ircevent
         ievent.bot = self
         ievent.sock = self.sock
-        chan = ievent.channel.lower()
+        chan = ievent.channel
 
         # check for /msg
-        if chan == self.nick.lower():
+        if chan == self.nick:
             ievent.msg = 1
             ievent.speed =  7
             ievent.printto = ievent.nick
@@ -432,7 +434,7 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
 
         # see if were adressed, if so dispatch
         txtlist = ievent.txt.split(':', 1)
-        if txtlist[0].lower() == self.nick.lower():
+        if txtlist[0]  == self.nick:
             if len(txtlist) < 2:
                 return
             ievent.txt = txtlist[1].strip()
@@ -441,7 +443,7 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
 
         # habbie addressing mode
         txtlist = ievent.txt.split(',', 1)
-        if txtlist[0].lower() == self.nick.lower():
+        if txtlist[0] == self.nick:
             if len(txtlist) < 2:
                 return
             ievent.txt = txtlist[1].strip()
@@ -458,11 +460,11 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         if ievent.nick in self.nicks401:
              rlog(10, self.name, "%s is available again" % ievent.nick)
              self.nicks401.remove(ievent.nick)
-        chan = ievent.channel.lower()
-        nick = ievent.nick.lower()
+        chan = ievent.channel
+        nick = ievent.nick
 
         # see if its the bot who is joining
-        if nick == self.nick.lower():
+        if nick == self.nick:
             # check if we already have a channels object, if not init it
             if not self.channels.has_key(chan):
                 self.channels[chan] = {}
@@ -473,12 +475,13 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
             if chan in self.state['opchan']:
                 self.state['opchan'].remove(chan)
                 self.state.save()
+            self.timejoined[chan] = time.time()
             time.sleep(0.5)
             periodical.addjob(10, 1, self.who, self, chan)
             return
 
         # sync joined user with userhosts cache
-        self.userhosts[nick] = ievent.userhost
+        self.userhosts.data[nick] = ievent.userhost
         self.userchannels.adduniq(nick, chan)
 
     def handle_kick(self, ievent):
@@ -490,11 +493,11 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         except IndexError:
             return
 
-        chan = ievent.channel.lower()
+        chan = ievent.channel
 
         # see if its the bot who got kicked .. if so remove from
         # joinedchannels
-        if who == self.nick.lower():
+        if who == self.nick:
             if chan in self.state['joinedchannels']:
                 self.state['joinedchannels'].remove(chan)
                 self.state.save()
@@ -504,14 +507,14 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         """ update userhost cache on nick change. """
 
         nick = ievent.txt
-        self.userhosts[nick.lower()] = ievent.userhost
+        self.userhosts.data[nick] = ievent.userhost
 
-        if ievent.nick.lower() == self.nick.lower():
+        if ievent.nick == self.nick:
             self.cfg['nick'] = nick
             self.cfg.save()
 
         try:
-            self.userchannels[nick.lower()] = self.userchannels[ievent.nick.lower()]
+            self.userchannels[nick] = self.userchannels[ievent.nick]
         except:
            raise
 
@@ -519,10 +522,10 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
 
         """ handle parts. """
 
-        chan = ievent.channel.lower()
+        chan = ievent.channel
 
         # see if its the bot who is parting
-        if ievent.nick.lower() == self.nick.lower():
+        if ievent.nick == self.nick:
             rlog(1, self.name, 'parted channel %s' % chan)
             # remove from joinedchannels
             if chan in self.state['joinedchannels']:
@@ -538,8 +541,8 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
             Irc.handle_ievent(self, ievent)
             # check for callbacks
             if ievent.cmnd == 'JOIN' or ievent.msg:
-                if ievent.nick.lower() in self.nicks401:
-                    self.nicks401.remove(ievent.nick.lower())
+                if ievent.nick in self.nicks401:
+                    self.nicks401.remove(ievent.nick)
             i = Ircevent()
             i.copyin(ievent)
             i.bot = self
@@ -553,7 +556,7 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         """ check if quit is because of a split. """
 
         if '*.' in ievent.txt or self.server in ievent.txt:
-            self.splitted.append(ievent.nick.lower())
+            self.splitted.append(ievent.nick)
         
     def handle_mode(self, ievent):
 
@@ -564,7 +567,7 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         try:
             dummy = ievent.arguments[2]
         except IndexError:
-            chan = ievent.channel.lower()
+            chan = ievent.channel
             # channel mode change has 2 arguments
             self.getchannelmode(chan)
             self.channels.set(chan, 'mode', ievent.arguments[1])    
@@ -574,24 +577,24 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         """ handle 311 response .. sync with userhosts cache. """
 
         target, nick, user, host, dummy = ievent.arguments
-        nick = nick.lower()
+        nick = nick
         userhost = "%s@%s" % (user, host)
         rlog(1, self.name, 'adding %s to userhosts: %s' % (nick, userhost))
         # userhosts cache is accessed by lower case nick
-        self.userhosts[nick] = userhost
+        self.userhosts.data[nick] = userhost
 
     def handle_352(self, ievent):
 
         """ handle 352 response .. sync with userhosts cache. """
 
         args = ievent.arguments
-        channel = args[1].lower()  
-        nick = args[5].lower()
+        channel = args[1]  
+        nick = args[5]
         user = args[2]
         host = args[3]
         userhost = "%s@%s" % (user, host)
         rlog(1, self.name, 'adding %s to userhosts: %s' % (nick, userhost))
-        self.userhosts[nick] = userhost
+        self.userhosts.data[nick] = userhost
         self.userchannels.adduniq(nick, channel)
 
     def handle_353(self, ievent):
@@ -599,9 +602,9 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
         """ handle 353 .. check if we are op. """
 
         userlist = ievent.txt.split()
-        chan = ievent.channel.lower()
+        chan = ievent.channel
         for i in userlist:
-            if i[0] == '@' and i[1:].lower() == self.nick.lower():
+            if i[0] == '@' and i[1:] == self.nick:
                 if chan not in self.state['opchan']:
                     self.state['opchan'].append(chan)
 
@@ -609,7 +612,7 @@ self.nick, self.server, self.ipv6, self.ssl, self.port)
 
         """ handle mode request responses. """
 
-        self.channels.set(ievent.channel.lower(), 'mode', ievent.arguments[2])
+        self.channels.set(ievent.channel, 'mode', ievent.arguments[2])
 
     def handle_invite(self, ievent):
 
