@@ -80,8 +80,8 @@ class Irc(BotBase):
         self.nicks401 = []
         self.stopreadloop = False
         self.stopoutloop = False
-        if self.port == 0:
-            self.port = 6667
+        self.port = self.cfg['port'] or 6667
+        rlog(10, self.name, "port is %s" % self.port)
         self.connectlock = thread.allocate_lock()
         self.encoding = 'utf-8'
 
@@ -112,7 +112,7 @@ class Irc(BotBase):
                 if errno != 32 and errno != 9:
                     raise
                 else:
-                    rlog(10, self.name, 'broken pipe/bad socket  error .. ignoring')
+                    time.sleep(0.5)
             except:
                 rlog(10, self.name, "ERROR: can't send %s" % str(ex))
                 self.reconnect()
@@ -319,8 +319,12 @@ class Irc(BotBase):
                 continue
 
             except IOError, ex:
-                if 'temporarily' in str(ex):
+                if self.blocking and 'temporarily' in str(ex):
+                    time.sleep(0.5)
                     continue
+                handle_exception()
+                reconnect = 1
+                break
 
             except Exception, ex:
                 if self.stopped or self.stopreadloop:
@@ -568,9 +572,9 @@ realname))
             if res:
                 self.connectok.wait()
                 self._onconnect()
-                self.connecting = False
                 self.connected = True
                 rlog(10, self.name, 'logged on !')
+            self.connecting = False
         except AlreadyConnecting:
             return 0 
         except AlreadyConnected:
@@ -629,6 +633,7 @@ realname))
 
         """ exit the bot. """
 
+        self.stopreadloop = 1
         self.stopped = 1
         self.connected = 0
         self.shutdown()
@@ -685,7 +690,7 @@ reconsleep)
         rlog(10, self.name + '.fakein', txt)
         self.handle_ievent(Ircevent().parse(self, txt))
 
-    def say(self, printto, what, who=None, how='msg', fromm=None, speed=0):
+    def say(self, printto, what, who=None, how='msg', fromm=None, speed=0, groupchat=False):
 
         """ say what to printto. """
 
@@ -825,7 +830,7 @@ reconsleep)
         if password:
             self._raw('JOIN %s %s' % (channel, password))
             try:
-                self.channels[channel.lower()]['key'] = password
+                self.channels[channel]['key'] = password
                 self.channels.save()
             except KeyError:
                 pass
@@ -910,7 +915,7 @@ reconsleep)
             except:
                 pass
             if not self.blocking and 'broken pipe' in str(ex).lower():
-                rlog(11, self.name, 'broken pipe error .. ignoring')
+                time.sleep(0.5)
             else:
                 rlog(11, self.name, 'send error: %s' % str(ex))
                 self.reconnect()
@@ -988,9 +993,9 @@ reconsleep)
 
         try:
             if ievent.cmnd == 'JOIN' or ievent.msg:
-                if ievent.nick.lower() in self.nicks401:
+                if ievent.nick in self.nicks401:
                     self.nicks401.remove(ievent.nick)
-                    rlog(10, self.name, '%s joined .. unignoring')
+                    rlog(10, self.name, '%s joined .. unignoring' % ievent.nick)
             # see if the irc object has a method to handle the ievent
             method = getattr(self,'handle_' + ievent.cmnd.lower())
             # try to call method
