@@ -34,21 +34,18 @@ import re, types, os, time
 # ========
 
 
-class JsonUser(LazyDict):
+class JsonUser(Persist):
 
     """ LazyDict representing a user. """
 
-    def __init__(self, name="", userhosts=[], perms=[], permits=[], status=[], email=[], d=None):
-        if not d:
-            LazyDict.__init__(self)
-            self.name = name
-            self.userhosts = userhosts
-            self.perms = perms
-            self.permits = permits
-            self.status = status
-            self.email = email
-        else:
-            LazyDict.__init__(self, d)
+    def __init__(self, name="", userhosts=[], perms=[], permits=[], status=[], email=[]):
+        Persist.__init__(self, u"users" + os.sep + name)
+        self.data.name = self.data.name or name
+        self.data.userhosts = self.data.userhosts or userhosts
+        self.data.perms = self.data.perms or perms
+        self.data.permits = self.data.permits or permits
+        self.data.status = self.data.status or status
+        self.data.email = self.data.email or email
 
 class JsonUsers(Persist):
 
@@ -58,16 +55,16 @@ class JsonUsers(Persist):
         self.datadir = ddir or datadir
         Persist.__init__(self, filename)
         if not self.data:
-            self.data = {}
-        self.users = self.data
+            self.data = LazyDict()
+        self.data.names = self.data.names or {}
 
     def all(self):
 
         """ get all users. """
 
         result = []
-        for userdata in self.data.values():
-            result.append(JsonUser(d=userdata))
+        for name in self.data['names'].values():
+            result.append(JsonUser(name))
         return result
 
     ### Misc. Functions
@@ -75,21 +72,18 @@ class JsonUsers(Persist):
 
         """ return nr of users. """
 
-        return len(self.users)
+        return len(self.data['names'])
 
     def names(self):
 
         """ get names of all users. """
 
-        result = []
-        for user in self.all():
-            result.append(user.name)
-        return result
+        return self.data.names
 
     def byname(self, name):
         """ return user by name. """ 
         try:
-            return JsonUser(d=self.users[name])
+            return JsonUser(name)
         except KeyError:
             return
 
@@ -104,18 +98,21 @@ class JsonUsers(Persist):
 
     def usersearch(self, userhost):
         """ search for users with a userhost like the one specified """
+
         result = []
-        for udata in self.users.values():
-            user = JsonUser(d=udata)
-            if userhost in user.userhosts:
-                 result.append((user.name, user.userhost))
+
+        for u, name in self.data.names.iteritems():
+
+            if userhost in u:
+                result.append((name, u))
+
         return result
 
     def getuser(self, userhost):
-        for userdata in self.users.values():
-            user = JsonUser(d=userdata)
-            if userhost in user.userhosts:
-                return user
+        try:
+            return JsonUser(self.data.names[userhost])
+        except KeyError:
+            return 
 
     ### Check functions
     def exist(self, name):
