@@ -18,25 +18,26 @@ from xmpp.monitor import xmppmonitor
 from utils.log import rlog
 from utils.exception import handle_exception
 from utils.generic import checkchan
-from utils.locking import lockdec
+from utils.locking import lockdec, funclocked, Locked
 from utils.generic import plugnames, waitforqueue, uniqlist, makeoptions, makeargrest, cleanpycfile
 from gozerimport import gozer_import, force_import
 from persist.persist import Persist
 from persist.persistconfig import PersistConfig
 from config import config
 from commands import cmnds
-from callbacks import callbacks, jcallbacks
+from callbacks import callbacks, jcallbacks, gn_callbacks
 from redispatcher import rebefore, reafter
-from aliases import aliascheck
+from aliases import aliascheck, aliasget
 from ignore import shouldignore
 from threads.thr import start_new_thread, getname
 from persist.persiststate import PersistState
 from simplejson import loads
 from morphs import inputmorphs, outputmorphs
 from eventbase import EventBase
+from admin import cmndtable, pluginlist
 
 # basic imports
-import os, os.path, thread, time, Queue, re
+import os, os.path, thread, time, Queue, re, copy
 
 ## END IMPORT
 
@@ -70,7 +71,9 @@ class Plugins(object):
         self.initcalled = [] # plugins which init functions are called
         self.overloads = {} # plugins to overload
         self.activated = {}
- 
+        for plug in config['plugdeny']:
+            self.disable(plug)
+
     def __getitem__(self, item):
 
         """
@@ -170,6 +173,7 @@ class Plugins(object):
             config.save()
             self.plugdeny.data.append(name)
             self.plugdeny.save()
+            
         except:
             pass
 
@@ -252,14 +256,9 @@ class Plugins(object):
                 :pyobject: Plugins.plugimport
 
         """
-
+        
         if name in config['loadlist']:
-            self.reload(mod, name)
-        #else:
-        #    self.reload(mod, name, enable=False)
-
-        if self.plugs.has_key(name):
-            return self.plugs[name]
+            return self.load(mod, name)
 
     def regplugin(self, mod, name):
 
@@ -283,11 +282,15 @@ class Plugins(object):
 
         # see if plugin is in deny
         if name in self.avail:
-            rlog(9, 'plugins', '%s already registered' % name)
+            rlog(0, 'plugins', '%s already registered' % name)
+            return
+
+        if name in config['plugdeny']:
+            rlog(0, 'plugins', '%s is in config.plugdeny .. not loading' % name)
             return
 
         if name in self.plugdeny.data:
-            rlog(10, 'plugins', '%s.%s in deny .. not loading' % \
+            rlog(0, 'plugins', '%s.%s in deny .. not loading' % \
 (mod, name))
             return 0
 
@@ -302,17 +305,27 @@ class Plugins(object):
             self.unloadnosave(name)
 
         # create the plugin data dir
-        if not os.path.isdir(datadir + os.sep + 'plugs'):
-            os.mkdir(datadir + os.sep + 'plugs')
+        if hasattr(os, 'mkdir'):
+            if not os.path.isdir(datadir + os.sep + 'plugs'):
+                os.mkdir(datadir + os.sep + 'plugs')
 
-        if not os.path.isdir(datadir + os.sep + 'plugs' + os.sep + name):
-            os.mkdir(datadir + os.sep + 'plugs' + os.sep + name)
+            if not os.path.isdir(datadir + os.sep + 'plugs' + os.sep + name):
+                os.mkdir(datadir + os.sep + 'plugs' + os.sep + name)
 
         # import the plugin
         plug = self.plugimport(mod, name)
-        rlog(0, 'plugins', "%s.%s registered" % (mod, name))
-        return plug
 
+        if plug:
+            rlog(0, 'plugins', "%s.%s registered" % (mod, name))
+
+            if name not in self.avail:
+                self.avail.append(name)
+
+            return plug
+
+        else:
+            rlog(10, 'plugins', "can't import %s.%s .. try plug-enable" % (mod, name))
+         
     def showregistered(self):
 
         """
@@ -369,7 +382,7 @@ class Plugins(object):
         self.plugdeny.init([])
         self.plugallow.init([])
         avail = [] 
-        plugs = gozer_import('gozerbot.plugs')
+        plugs = force_import('gozerbot.plugs')
 
         for i in plugs.__plugs__:
 
@@ -379,8 +392,8 @@ class Plugins(object):
                     self.regplugin('gozerbot.plugs', i)
                 except Exception, ex:
                     handle_exception()
-
-                avail.append(i)
+                else:
+                    avail.append(i)
 
         self.ondisk.extend(avail)
 
@@ -426,25 +439,20 @@ class Plugins(object):
 
         # check for gozerplugs package
         try:
-            plugs = gozer_import('gozerplugs')
+            gplugs = gozer_import('gozerplugs')
         except ImportError:
             rlog(20, 'plugins', "no gozerplugs package found")
-            plugs = None
+            gplugs = None
 
-        if plugs:
+        if gplugs:
 
-            for i in plugs.__plugs__:
+            for i in gplugs.__plugs__:
 
-                if i not in avail:
-
-                    try:
-                        self.regplugin('gozerplugs', i)
-                        avail.append(i)
-                    except Exception, ex:
-                        handle_exception()
-
-                else:
-                    rlog(10, 'plugins', '%s already loaded' % i)
+                try:
+                    self.regplugin('gozerplugs', i)
+                    avail.append(i)
+                except Exception, ex:
+                    handle_exception()
 
         self.ondisk.extend(avail)
         self.readoverload()
@@ -508,7 +516,7 @@ provided for %s" % funcname)
         for funcname, perms in self.overloads.iteritems():
 
             if self.permoverload(funcname, perms):
-                rlog(10, 'plugins', '%s permission set to %s' % (funcname, \
+                rlog(0, 'plugins', '%s permission set to %s' % (funcname, \
 perms))
 
     def available(self):
@@ -700,15 +708,18 @@ perms))
         return depends
 
     def load(self, mod , name, enable=True):
+        #if name in config['plugdeny']:
+        #     return
         # force an import of the plugin
         modname = mod + '.' + name
         self.down(name)
         self.unload(name)
         if enable:
             self.enable(name)
-        plug = self.plugs[name] = force_import(modname)
+        plug = self.plugs[name] = gozer_import(modname)
         plug.loadtime = time.time()
         if enable:
+            self.enable(name)
             self.overload()
             # call plugins init() function
             try:
@@ -728,13 +739,13 @@ perms))
         self.activate(name)
         return plug
 
-    @loadlocked
+    #@loadlocked
     def reload(self, mod, name, enable=True):
 
         """
             reload plugin.
 
-            :param mod: moduel to import plugin from
+            :param mod: module to import plugin from
             :type mod: string
             :param name: name of the plugin to reload
             :type name: string
@@ -747,7 +758,6 @@ perms))
 
         """
 
-
         # create the plugin data dir
         if not os.path.isdir(datadir + os.sep + 'plugs'):
             os.mkdir(datadir + os.sep + 'plugs')
@@ -773,7 +783,14 @@ perms))
         rlog(0, 'plugins', 'reloaded plugin %s' % modname)
         reloaded.append(name)
         self.plugallow.data.append(name)
-        self.avail.append(name)
+
+        try:
+            self.plugdeny.data.remove(name)
+        except ValueError:
+            pass
+
+        if name not in self.avail:
+            self.avail.append(name)
 
         # recurse on plugins the depend on this plugin
         try:
@@ -794,6 +811,7 @@ perms))
         try:
             cmnds.activate(plugname)
             callbacks.activate(plugname)
+            gn_callbacks.activate(plugname)
             jcallbacks.activate(plugname)
             rebefore.activate(plugname)
             reafter.activate(plugname)
@@ -812,6 +830,7 @@ perms))
         try:
             cmnds.disable(plugname)
             callbacks.disable(plugname)
+            gn_callbacks.disable(plugname)
             jcallbacks.disable(plugname)
             rebefore.disable(plugname)
             reafter.disable(plugname)
@@ -847,6 +866,8 @@ perms))
             plug = self.plugs[plugname]
 
             for p in plug.__plugs__:
+                if p == plug:
+                    raise Exception("same plugin name as dir name (%s)" % plugname)
                 unloaded.extend(self.unload(p))
 
         except (KeyError, AttributeError):
@@ -857,6 +878,12 @@ perms))
             self.saveplug(plugname)
             self.unloadnosave(plugname)
 
+            try:
+                self.avail.remove(plugname)
+
+            except ValueError:
+                pass
+
         return unloaded
 
     def unloadnosave(self, plugname):
@@ -876,9 +903,11 @@ perms))
         # call shutdown function
         try:
             self.plugs[plugname].shutdown()
-            rlog(0, 'plugins', '%s shutdown called' % plugname)
+            rlog(10, 'plugins', '%s shutdown called' % plugname)
+
         except (AttributeError, KeyError):
             pass
+
         except Exception, ex:
             handle_exception()
 
@@ -904,6 +933,7 @@ perms))
         try:
             cmnds.unload(plugname)
             callbacks.unload(plugname)
+            gn_callbacks.unload(plugname)
             jcallbacks.unload(plugname)
             rebefore.unload(plugname)
             reafter.unload(plugname)
@@ -980,17 +1010,18 @@ perms))
                 :pyobject: Plugins.woulddispatch
 
         """
-
+        #self.needreloadcheck(bot, ievent)
         (what, command) = self.dispatchtest(bot, ievent)
 
-        if what and not what.activate:
-            return False
+        #if what and not what.activate:
+        #    return False
 
         if what and command:
             return True
 
         return False
 
+    #@funclocked
     def dispatchtest(self, bot, ievent, direct=False):
 
         """
@@ -1057,8 +1088,18 @@ perms))
 
             # check for auto registration
             if config['auto_register'] and not users.getname(ievent.userhost):
-                users.add("%s!%s" % (ievent.nick, ievent.userhost) , \
-[ievent.userhost, ], ['USER', ])
+                if bot.google:
+                    users.add(ievent.userhost , [ievent.userhost, ], ['USER', ])
+                elif not bot.jabber:
+                    users.add("%s!%s" % (ievent.nick, ievent.userhost) , [ievent.userhost, ], ['USER', ])
+                    bot.ratelimit(ievent.userhost, 20)
+                else:
+                    if ievent.groupchat:
+                        users.add(ievent.userhost , [ievent.userhost, ], ['USER', ])
+                        bot.ratelimit(ievent.userhost)
+                    else:
+                        users.add(ievent.stripped , [ievent.stripped, ], ['USER', ])
+                        bot.ratelimit(ievent.stripped, 20)
 
             # check for anon access
             if config['anon_enable'] and not 'OPER' in result[1].perms:
@@ -1179,6 +1220,8 @@ perms))
         # see if ievent would dispatch
         # what is rebefore, cmnds of reafter, com is the command object
         # check if redispatcher or commands object needs to be used
+        #self.needreloadcheck(bot, ievent)
+
         (what, com) = self.dispatchtest(bot, ievent, direct)
 
         if what:
@@ -1256,15 +1299,7 @@ perms))
 
         """
 
-        if bot.type == 'irc':
-            from irc.ircevent import Ircevent
-            ie = Ircevent(event, bot)
-        elif bot.type == 'xmpp' or bot.type == 'jabber':
-            from xmpp.message import Message
-            ie = Message(event, bot)
-        else:
-            rlog(100, self.name, 'unsupported bot type: %s' % bot.type)
-            return
+        ie = copy.deepcopy(event)
         return ie
 
 
@@ -1287,6 +1322,7 @@ perms))
         for i in ievent.txt.split(' && '):
             ie = self.clonedevent(bot, ievent)
             ie.txt = i
+            #self.needreloadcheck(bot, ievent)
             self.trydispatch(bot, ie)
 
     def splitpipe(self, bot, ievent):
@@ -1313,8 +1349,10 @@ perms))
         for i in txt.split(' | '):
             item = i.replace(' ##', ' | ')
             ie = self.clonedevent(bot, ievent)
+            ie.userhost = ievent.userhost
             ie.onlyqueues = True
             ie.txt = item.strip()
+            #self.needreloadcheck(bot, ie)
             events.append(ie)
 
         # loop over events .. chain queues
@@ -1345,6 +1383,44 @@ perms))
             if what:
                 self.dispatch(what, com, bot, i)
 
+    def needreloadcheck(self, bot, event, target=None):
+
+        if cmndtable:
+
+            try: 
+                if target:
+                    rlog(10, 'plugins', 'target set: %s' % target)
+                    cmnd = 'target-set'
+                    plugin = target
+                else:
+                    t = event.txt.split()[0]
+                    cmnd = aliasget(t) or t
+                    plugin = cmndtable[cmnd]
+
+                rlog(10, 'plugins', 'cmnd: %s plugin: %s' % (cmnd, plugin))
+
+                if self.exist(plugin):
+                    return
+
+                try:
+                    self.reload('gozerbot.plugs', plugin)
+                except ImportError, ex:
+
+                    try:
+                        self.reload('gozerplugs', plugin)
+                    except ImportError, ex:
+
+                        try:
+                            self.reload('myplugs', plugin)
+                        except ImportError, ex:
+                            return
+
+                rlog(100, 'plugins', 'reloaded %s' % plugin)
+
+            except KeyError, ex:
+                rlog(10, 'plugins', "can't find plugin to reload for %s" % event.txt.split()[0])
+
+
     def listreload(self, pluglist):
 
         """
@@ -1386,3 +1462,4 @@ perms))
 plugins = Plugins()
 
 ## END INIT
+
