@@ -33,12 +33,19 @@ from gozerbot.runner import cbrunners, cmndrunners
 from gozerbot.tests import tests
 import gozerbot.utils.log
 
+from simplejson import loads
+
 # basic imports
 from sets import Set
 import time, threading, sys, re, os, copy
 
 plughelp.add('core', 'core commands for the bot')
 
+try:
+    pluginlist = loads(open('pluginlist').read())
+except:
+    pluginlist = []
+
 def handle_rusage(bot, ievent):
 
     """ show resource usage. """
@@ -118,12 +125,13 @@ def handle_list(bot, ievent):
     """ list [<plugin>] .. list loaded plugins or list commands provided by \
         plugin.
     """
+    global pluginlist
 
     try:
         what = ievent.args[0]
-    except:
+    except IndexError:
         # no arguments given .. show plugins
-        ievent.reply('\002loaded plugins:\002 ', plugins.list())
+        ievent.reply('loaded plugins: ', plugins.list())
         return
 
     # show commands of <what> plugin
@@ -415,7 +423,7 @@ def handle_loglevel(bot, ievent):
     """ loglevel <level> .. get or set loglevel. the lower the more the bot logs. """
 
     if len(ievent.args) == 0:
-        ievent.reply('loglevel is %s' % config['loglevel'])
+        ievent.reply('loglevel is %s' % str(gozerbot.utils.log.loglevel))
         return
 
     try:
@@ -653,16 +661,16 @@ def handle_help(bot, ievent):
     try:
         what = ievent.args[0]
     except IndexError:
-        ievent.reply('help <cmnd> or help <plugin> .. see the !list \
-command for a list of available plugins or see !available command for a list \
-of plugins to be reloaded')
+        ievent.reply('run help on one of the following plugins: ', pluginlist)
         return
 
+    plugins.needreloadcheck(bot, ievent, what)
     phelp = plughelp.get(what)
     cmndresult = []
 
     if phelp:
         ievent.reply('plugin description: %s' % phelp)
+
         perms = list(users.getperms(ievent.userhost))
 
         for i, j in cmnds.iteritems():
