@@ -14,7 +14,7 @@ from gozerbot.utils.name import stripname
 from gozerbot.users import users
 from gozerbot.commands import cmnds
 from gozerbot.examples import examples
-from gozerbot.aliases import aliases, aliasdel
+from gozerbot.aliases import aliasdel, aliasset
 from gozerbot.plughelp import plughelp
 from gozerbot.tests import tests
 
@@ -28,7 +28,7 @@ def handle_whoami(bot, ievent):
 
 cmnds.add('user-whoami', handle_whoami, 'USER')
 examples.add('user-whoami', 'get your username', 'user-whoami')
-aliases.data['whoami'] = 'user-whoami'
+aliasset('whoami', 'user-whoami')
 tests.add('whoami')
 
 def handle_meet(bot, ievent):
@@ -36,7 +36,7 @@ def handle_meet(bot, ievent):
     """ user-meet <nick> .. introduce a new user to the bot. """
 
     try:
-        nick = ievent.args[0].lower()
+        nick = ievent.args[0]
     except IndexError:
         ievent.missing('<nick>')
         return
@@ -60,11 +60,7 @@ def handle_meet(bot, ievent):
 
     result = 0
     name = stripname(nick.lower())
-    try:
-        result = users.add(name, [userhost, ], ['USER', ])
-    except Exception, ex:
-        ievent.reply('ERROR: %s' % str(ex))
-        return
+    result = users.add(name, [userhost, ], ['USER', ])
 
     if result:
         ievent.reply('%s (%s) added to user database' % (nick, name))
@@ -74,7 +70,7 @@ def handle_meet(bot, ievent):
 cmnds.add('user-meet', handle_meet, ['OPER', 'MEET'])
 examples.add('user-meet', 'user-meet <nick> .. introduce <nick> to the \
 bot', 'user-meet dunker')
-aliases.data['meet'] = 'user-meet'
+aliasset('meet', 'user-meet')
 tests.add('meet test').add('delete test')
 
 def handle_adduser(bot, ievent):
@@ -96,11 +92,7 @@ def handle_adduser(bot, ievent):
 
     result = 0
     name = stripname(name.lower()) 
-    try:
-        result = users.add(name, [userhost, ], ['USER', ])
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.add(name, [userhost, ], ['USER', ])
 
     if result:
         ievent.reply('%s added to user database' % name)
@@ -147,12 +139,7 @@ user"):
 (userhost, username))
         return
 
-    result = 0
-    try:
-        result = users.merge(name, userhost)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.merge(name, userhost)
 
     if result:
         ievent.reply('%s merged' % nick)
@@ -162,7 +149,7 @@ user"):
 cmnds.add('user-merge', handle_merge, ['OPER', 'MEET'])
 examples.add('user-merge', 'user-merge <name> <nick> .. merge record with \
 <name> with userhost from <nick>', 'merge bart dunker')
-aliases.data['merge'] = 'user-merge'
+aliasset('merge', 'user-merge')
 tests.add('user-add mtest2 mekker@test2').add('merge mtest2 bottest', 'bottest merged').add('delete mtest2')
 
 def handle_delete(bot, ievent):
@@ -182,11 +169,7 @@ def handle_delete(bot, ievent):
     result = 0
     #name = stripname(name.lower())
     name = name.lower()
-    try:
-        result = users.delete(name)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.delete(name)
 
     if result:
         ievent.reply('%s deleted' % name)
@@ -195,7 +178,7 @@ def handle_delete(bot, ievent):
 
 cmnds.add('user-del', handle_delete, 'OPER')
 examples.add('user-del', 'user-del <name> .. delete user with <username>' , 'user-del dunker')
-aliases.data['delete'] = 'user-del'
+aliasset('delete', 'user-del')
 tests.add('user-add mtest3 mekker@test3').add('delete mtest3', 'mtest3 deleted')
 
 def handle_userscan(bot, ievent):
@@ -224,7 +207,7 @@ def handle_userscan(bot, ievent):
 
 cmnds.add('user-scan', handle_userscan, 'OPER')
 examples.add('user-scan', 'user-scan <txt> .. search database for matching usernames', 'user-scan dunk')
-aliases.data['us'] = 'user-scan'
+aliasset('us', 'user-scan')
 tests.add('user-add mtest4 mekker@test4').add('user-scan mte', 'mtest4').add('delete mtest4')
 
 def handle_names(bot, ievent):
@@ -235,7 +218,7 @@ def handle_names(bot, ievent):
 
 cmnds.add('user-names', handle_names, 'OPER')
 examples.add('user-names', 'show names of registered users', 'user-names')
-aliases.data['names'] = 'user-names'
+aliasset('names', 'user-names')
 tests.add('user-add mtest5 mekker@test').add('user-names', 'mtest5').add('delete mtest5')
 
 def handle_name(bot, ievent):
@@ -246,7 +229,7 @@ def handle_name(bot, ievent):
 
 cmnds.add('user-name', handle_name, 'USER')
 examples.add('user-name', 'show name of user giving the commands', 'user-name')
-aliases.data['name'] = 'user-name'
+aliasset('name', 'user-name')
 tests.add('user-name', 'exec')
 
 def handle_getname(bot, ievent):
@@ -273,8 +256,8 @@ def handle_getname(bot, ievent):
 
 cmnds.add('user-getname', handle_getname, 'USER')
 examples.add('user-getname', 'user-getname <nick> .. get the name of <nick>', 'user-getname dunker')
-aliases.data['gn'] = 'user-getname'
-aliases.data['getname'] = 'user-getname'
+aliasset('gn', 'user-getname')
+aliasset('getname', 'user-getname')
 tests.add('user-getname test')
 
 def handle_addperm(bot, ievent):
@@ -299,11 +282,7 @@ def handle_addperm(bot, ievent):
         ievent.reply('%s already has permission %s' % (name, perm))
         return         
 
-    try:
-        result = users.adduserperm(name, perm)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.adduserperm(name, perm)
 
     if result:
         ievent.reply('%s perm added' % perm)
@@ -312,8 +291,8 @@ def handle_addperm(bot, ievent):
 
 cmnds.add('user-addperm', handle_addperm, 'OPER')
 examples.add('user-addperm', 'user-addperm <name> <perm> .. add permissions to user <name>', 'user-addperm dunker rss')
-aliases.data['setperms'] = 'user-addperm'
-aliases.data['addperms'] = 'user-addperm'
+aliasset('setperms', 'user-addperm')
+aliasset('addperms', 'user-addperm')
 tests.add('user-add mtest6 mekker@test6', 'mtest6').add('user-addperm mtest6 mekker', 'MEKKER perm added').add('delete mtest6')
 
 def handle_getperms(bot, ievent):
@@ -339,7 +318,7 @@ def handle_getperms(bot, ievent):
 
 cmnds.add('user-getperms', handle_getperms, 'OPER')
 examples.add('user-getperms', 'user-getperms <name> .. get permissions of <name>', 'user-getperms dunker')
-aliases.data['getperms'] = 'user-getperms'
+aliasset('getperms', 'user-getperms')
 tests.add('user-add mtest7 mekker@test7').add('user-addperm mtest7 mekker').add('user-getperms mtest7' , 'MEKKER').add('delete mtest7')
 
 def handle_perms(bot, ievent):
@@ -361,7 +340,7 @@ def handle_perms(bot, ievent):
 
 cmnds.add('user-perms', handle_perms, 'USER')
 examples.add('user-perms', 'get permissions', 'user-perms')
-aliases.data['perms'] = 'user-perms'
+aliasset('perms', 'user-perms')
 tests.add('user-perms', 'USER')
 
 def handle_delperm(bot, ievent):
@@ -380,12 +359,7 @@ def handle_delperm(bot, ievent):
         ievent.reply("can't find user %s" % name)
         return
 
-    result = 0
-    try:
-        result = users.deluserperm(name, perm)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.deluserperm(name, perm)
 
     if result:
         ievent.reply('%s perm removed' % perm)
@@ -413,16 +387,11 @@ def handle_addstatus(bot, ievent):
         ievent.reply("can't find user %s" % name)
         return
 
-    result = 0
     if users.gotstatus(name, status):
         ievent.reply('%s already has status %s' % (name, status))
         return
 
-    try:
-        result = users.adduserstatus(name, status)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.adduserstatus(name, status)
 
     if result:
         ievent.reply('%s status added' % status)
@@ -431,8 +400,8 @@ def handle_addstatus(bot, ievent):
 
 cmnds.add('user-addstatus', handle_addstatus, 'OPER')
 examples.add('user-addstatus', 'user-addstatus <name> <status>', 'user-addstatus dunker #dunkbots')
-aliases.data['setstatus'] = 'user-addstatus'
-aliases.data['addstatus'] = 'user-addstatus'
+aliasset('setstatus', 'user-addstatus')
+aliasset('addstatus', 'user-addstatus')
 tests.add('user-add mtest9 mekker@test9').add('user-addstatus mtest9 mekker', 'MEKKER status added').add('delete mtest9')
 
 def handle_getstatus(bot, ievent):
@@ -458,7 +427,7 @@ def handle_getstatus(bot, ievent):
 
 cmnds.add('user-getstatus', handle_getstatus, 'OPER')
 examples.add('user-getstatus', 'user-getstatus <name> .. get status of <name>', 'user-getstatus dunker')
-aliases.data['getstatus'] = 'user-getstatus'
+aliasset('getstatus', 'user-getstatus')
 tests.add('user-add mtest10 mekker@test10').add('user-addstatus mtest10 mekker', 'MEKKER status added').add('user-getstatus mtest10', 'MEKKER').add('delete mtest10')
 
 def handle_status(bot, ievent):
@@ -472,7 +441,7 @@ def handle_status(bot, ievent):
 
 cmnds.add('user-status', handle_status, 'USER')
 examples.add('user-status', 'get status', 'user-status')
-aliases.data['status'] = 'user-status'
+aliasset('status', 'user-status')
 tests.add('user-status')
 
 def handle_delstatus(bot, ievent):
@@ -491,12 +460,7 @@ def handle_delstatus(bot, ievent):
         ievent.reply("can't find user %s" % name)
         return
 
-    result = 0
-    try:
-        result = users.deluserstatus(name, status)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.deluserstatus(name, status)
 
     if result:
         ievent.reply('%s status deleted' % status)
@@ -506,7 +470,7 @@ def handle_delstatus(bot, ievent):
 
 cmnds.add('user-delstatus', handle_delstatus, 'OPER')
 examples.add('user-delstatus', 'user-delstatus <name> <status>', 'user-delstatus dunker #dunkbots')
-aliases.data['delstatus'] = 'user-delstatus'
+aliasset('delstatus', 'user-delstatus')
 tests.add('user-add mtest11 mekker@test11').add('user-addstatus mtest11 mekker').add('user-delstatus mtest11 mekker', 'MEKKER status deleted').add('delete mtest11')
 
 def handle_adduserhost(bot, ievent):
@@ -531,12 +495,7 @@ owner'):
         ievent.reply('%s already has userhost %s' % (name, userhost))
         return
 
-    result = 0
-    try:
-        result = users.adduserhost(name, userhost)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.adduserhost(name, userhost)
 
     if result:
         ievent.reply('userhost added')
@@ -545,8 +504,8 @@ owner'):
 
 cmnds.add('user-adduserhost', handle_adduserhost, 'OPER')
 examples.add('user-adduserhost', 'user-adduserhost <name> <userhost>', 'user-adduserhost dunker bart@%.a2000.nl')
-aliases.data['adduserhost'] = 'user-adduserhost'
-aliases.data['adduserhosts'] = 'user-adduserhost'
+aliasset('adduserhost', 'user-adduserhost')
+aliasset('adduserhosts', 'user-adduserhost')
 tests.add('user-add mtest12 mekker@test12').add('user-adduserhost mtest12 mekker2@test122', 'userhost added').add('delete mtest12')
 
 def handle_deluserhost(bot, ievent):
@@ -567,12 +526,7 @@ from owner'):
         ievent.reply("can't find user %s" % name)
         return
 
-    result = 0
-    try:
-        result = users.deluserhost(name, userhost)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.deluserhost(name, userhost)
 
     if result:
         ievent.reply('userhost removed')
@@ -583,8 +537,8 @@ userhost))
 
 cmnds.add('user-deluserhost', handle_deluserhost, 'OPER')
 examples.add('user-deluserhost', 'user-deluserhost <name> <userhost> .. delete from usershosts of <name> userhost <userhost>','user-deluserhost dunker bart1@bla.a2000.nl')
-aliases.data['deluserhost'] = 'user-deluserhost'
-aliases.data['deluserhosts'] = 'user-deluserhost'
+aliasset('deluserhost', 'user-deluserhost')
+aliasset('deluserhosts', 'user-deluserhost')
 tests.add('user-add mtest32 mekker@test32').add('user-adduserhost mtest12 mekker2@test32').add('user-deluserhost mtest12 mekker2@test32', 'userhost removed').add('delete mtest32')
 
 def handle_getuserhosts(bot, ievent):
@@ -606,7 +560,7 @@ def handle_getuserhosts(bot, ievent):
 
 cmnds.add('user-getuserhosts', handle_getuserhosts, 'OPER')
 examples.add('user-getuserhosts', 'user-getuserhosts <name> .. get userhosts of <name>', 'getuserhosts dunker')
-aliases.data['getuserhosts'] = 'user-getuserhosts'
+aliasset('getuserhosts', 'user-getuserhosts')
 tests.add('user-add mtest13 mekker@test13').add('user-adduserhost mtest13 mekker@test13').add('user-getuserhosts mtest13', 'mekker@test13').add('delete mtest13')
 
 def handle_userhosts(bot, ievent):
@@ -619,7 +573,7 @@ def handle_userhosts(bot, ievent):
 
 cmnds.add('user-userhosts', handle_userhosts, 'USER')
 examples.add('user-userhosts', 'get userhosts', 'user-userhosts')
-aliases.data['userhosts'] = 'user-userhosts'
+aliasset('userhosts', 'user-userhosts')
 tests.add('user-userhosts')
 
 def handle_getemail(bot, ievent):
@@ -645,7 +599,7 @@ def handle_getemail(bot, ievent):
 
 cmnds.add('user-getemail', handle_getemail, 'USER')
 examples.add('user-getemail', 'user-getemail <name> .. get email from user <name>', 'user-getemail dunker')
-aliases.data['getemail'] = 'user-getemail'
+aliasset('getemail', 'user-getemail')
 tests.add('user-add mtest14 mekker@test14').add('user-setemail mtest14 mekker@test14').add('user-getemail mtest14', 'mekker@test14').add('delete mtest14')
 
 def handle_setemail(bot, ievent):
@@ -667,7 +621,7 @@ def handle_setemail(bot, ievent):
 
 cmnds.add('user-setemail', handle_setemail, 'OPER')
 examples.add('user-setemail', 'user-setemail <name> <email>.. set email of user <name>', 'user-setemail dunker bart@gozerbot.org')
-aliases.data['setemail'] = 'user-setemail'
+aliasset('setemail', 'user-setemail')
 tests.add('user-add mtest15 mekker@test15').add('user-setemail mtest15 mekker@test15', 'email set').add('delete mtest15')
 
 def handle_email(bot, ievent):
@@ -687,7 +641,7 @@ email shows your own mail address')
 
 cmnds.add('user-email', handle_email, 'USER')
 examples.add('user-email', 'get email', 'user-email')
-aliases.data['email'] = 'user-email'
+aliasset('email', 'user-email')
 tests.add('user-setemail mekker@mekker').add('user-email', 'mekker@mekker')
 
 def handle_delemail(bot, ievent):
@@ -699,12 +653,7 @@ def handle_delemail(bot, ievent):
         ievent.reply("can't find user for %s" % ievent.userhost)
         return
 
-    result = 0
-    try:
-        result = users.delallemail(name)
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.delallemail(name)
 
     if result:
         ievent.reply('email removed')
@@ -713,7 +662,7 @@ def handle_delemail(bot, ievent):
 
 cmnds.add('user-delemail', handle_delemail, 'OPER')
 examples.add('user-delemail', 'reset email', 'user-delemail')
-aliases.data['delemail'] = 'user-delemail'
+aliasset('delemail', 'user-delemail')
 tests.add('user-setemail mekker@email').add('user-delemail', 'email removed')
 
 def handle_addpermit(bot, ievent):
@@ -735,17 +684,7 @@ def handle_addpermit(bot, ievent):
         ievent.reply('%s is already allowed to do %s' % (who, what))
         return
 
-    result = 0
-    try:
-        result = users.adduserpermit(name, who, what)
-    except RuntimeError, ex:
-        if 'recursion' in str(ex):
-            ievent.reply('this command is looping ..PLZ FIX!')
-            return
-    except Exception, ex:
-        handle_exception()
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.adduserpermit(name, who, what)
 
     if result:
         ievent.reply('permit added')
@@ -780,7 +719,7 @@ command shows what permits you have")
 
 cmnds.add('user-permit', handle_permit, 'USER')
 examples.add('user-permit', 'show permit of user giving the command', 'user-permit')
-aliases.data['permit'] = 'user-permit'
+aliasset('permit', 'user-permit')
 tests.add('user-add mtest17 mekker@test17').add('user-addpermit mtest17 todo', 'permit added').add('user-delpermit mtest17 todo').add('delete mtest17')
 
 def handle_userdelpermit(bot, ievent):
@@ -801,12 +740,7 @@ def handle_userdelpermit(bot, ievent):
         ievent.reply('%s is already not allowed to do %s' % (who, what))
         return
 
-    result = 0
-    try:
-        result = users.deluserpermit(name, (who, what))
-    except Exception, ex:
-        ievent.reply("ERROR: %s" % str(ex))
-        return
+    result = users.deluserpermit(name, (who, what))
 
     if result:
         ievent.reply('%s denied' % what)
@@ -847,7 +781,7 @@ def handle_check(bot, ievent):
 
 cmnds.add('user-check', handle_check, 'OPER')
 examples.add('user-check', 'user-check <nick>', 'user-check dunker')
-aliases.data['check'] = 'user-check'
+aliasset('check', 'user-check')
 tests.add('user-add mtest19 mekker@test19').add('user-check mtest19', 'mekker@test19').add('delete mtest19')
 
 def handle_show(bot, ievent):
@@ -901,7 +835,7 @@ def handle_match(bot, ievent):
 
 cmnds.add('user-match', handle_match, ['USER', 'OPER'])
 examples.add('user-match', 'user-match <userhost>', 'user-match test@test')
-aliases.data['match'] = 'user-match'
+aliasset('match', 'user-match')
 tests.add('user-add mtest21 mekker@test21').add('user-match mekker@test21', 'mekker@test21').add("delete mtest21")
 
 def handle_getuserstatus(bot, ievent):
