@@ -21,7 +21,7 @@ from gozerbot.config import config
 from gozerbot.jsonusers import JsonUsers
 
 # basic imports
-import re, types, os, time, thread
+import re, types, os, time, thread, sqlalchemy
 
 ## END IMPORT
 
@@ -33,14 +33,17 @@ deletelocked = lockdec(deletelock)
 ## END LOCK
 
 # see if we need to use the database or use the jsonusers
-if not config['nodb']:
-    from gozerbot.database.alchemy import create_session, \
-    UserHost, User, Perms, Statuses, query, getuser, byname, dblocked, trans, eagerload
-else:
-    def trans(func, *args, **kwargs):
-        def transaction(*args, **kwargs):
-            func(*args, **kwargs)
-        return transaction
+
+if True:
+    if not config['nodb']:
+        from gozerbot.database.alchemy import create_session, \
+        UserHost, User, Perms, Statuses, query, getuser, byname, dblocked, trans, eagerload
+
+    else:
+        def trans(func, *args, **kwargs):
+            def transaction(*args, **kwargs):
+                func(*args, **kwargs)
+            return transaction
 
 
 class DbUsers(object):
@@ -63,8 +66,8 @@ class DbUsers(object):
                 :pyobject: DbUsers.size
         """
 
-        return query(User).count()
-
+        return int(query(User).count())
+        
     def names(self):
 
         """
@@ -76,8 +79,8 @@ class DbUsers(object):
                 :pyobject: DbUsers.names
 
         """
-
-        return [n.name for n in query(User).all()]
+        a = query(User).all()
+        return [n.name for n in a]
 
     @trans
     def merge(self, session, name, userhost):
@@ -104,7 +107,7 @@ class DbUsers(object):
 
             if name not in user.userhosts:
                 user.userhosts.append(userhost)
-                #session.commit()
+                session.commit()
                 session.refresh(user)
                 rlog(10, 'users', "%s merged with %s" % (userhost, name))
                 return True
@@ -135,14 +138,19 @@ class DbUsers(object):
             see if user with <name> exists.
 
             :param name: name of the user
-            :rtype: gozerbot.database.alchemy.User or None
+            :rtype: boolean
 
             .. literalinclude:: ../../gozerbot/users.py
                 :pyobject: DbUsers.exist
 
         """
 
-        return byname(name)
+        a = byname(name)
+
+        if a:
+            return True
+
+        return False
 
     def allowed(self, userhost, perms, log=True):
 
@@ -246,9 +254,12 @@ class DbUsers(object):
         """
 
         user = byname(name)
+
         if user:
             return userhost in user.userhosts
 
+        return False
+
     def gotperm(self, name, perm):
 
         """
@@ -264,6 +275,8 @@ class DbUsers(object):
         if user:
             return perm.upper() in user.perms
 
+        return False
+
     def gotpermit(self, name, permit):
 
         """
@@ -279,7 +292,9 @@ class DbUsers(object):
 
         if user:
             return '%s %s' % permit in user.permits
-        
+
+        return ""
+
     def gotstatus(self, name, status):
 
         """
@@ -294,6 +309,8 @@ class DbUsers(object):
         if user:
             return status.upper() in user.statuses
 
+        return False
+
     ### Get Functions
     def getname(self, userhost):
 
@@ -310,6 +327,8 @@ class DbUsers(object):
         if user:
             return str(user.name)
 
+        return ""
+
     def gethosts(self, userhost):
 
         """ 
@@ -324,6 +343,8 @@ class DbUsers(object):
 
         if user:
             return list(user.userhosts)
+
+        return []
     
     def getemail(self, userhost):
 
@@ -340,6 +361,8 @@ class DbUsers(object):
             if user.email:
                 return str(user.email[0])
 
+        return ""
+
     def getperms(self, userhost):
 
         """
@@ -355,6 +378,8 @@ class DbUsers(object):
         if user:
             return list(user.perms)
 
+        return []
+
     def getpermits(self, userhost):
 
         """
@@ -370,6 +395,8 @@ class DbUsers(object):
         if user:
             return list(user.permits)
 
+        return []
+
     def getstatuses(self, userhost):
 
         """
@@ -466,8 +493,7 @@ class DbUsers(object):
                 :pyobject: DbUsers.getpermusers
 
         """
-        s = create_session()
-        n = query(Perms, s).filter(Perms.perm==perm.upper()).all()
+        n = query(Perms).filter(Perms.perm==perm.upper()).all()
         return [user.name for user in n]
 
     def getstatususers(self, status):
@@ -532,7 +558,7 @@ class DbUsers(object):
             rlog(10, 'users', 'i need a list of userhosts')
             return False
 
-        name = stripname(name)
+        name = stripname(name.lower())
 
         if not os.path.isdir(self.datadir + os.sep + 'users'):
             os.mkdir(self.datadir + os.sep + 'users')
@@ -551,9 +577,14 @@ class DbUsers(object):
                 session.add(newuser)
                 session.commit()
 
+            except sqlalchemy.exc.IntegrityError, ex:
+                if 'not unique' in str(ex):
+                    rlog(10, 'users', '%s %s already exists' % (name, userhosts))
+                    return True
+                else:
+                    raise
             except Exception, ex:
-                rlog(10, 'users', str(ex))
-                return
+                raise
 
             rlog(10, 'users', '%s %s %s added to user database' % (name, userhosts, perms))
 
@@ -574,7 +605,7 @@ class DbUsers(object):
 
         if user:
             user.email.append(email)
-            #session.commit()
+            session.commit()
             session.refresh(user)
             rlog(10, 'users', '%s (%s) added to email' % (email, userhost))
             return True
@@ -596,7 +627,7 @@ class DbUsers(object):
 
         if user:
             user.perms.append(perm.upper())
-            #session.commit()
+            session.commit()
             session.refresh(user)
             rlog(10, 'users', '%s perm %s added' % (userhost, perm))
             return True
@@ -619,7 +650,7 @@ class DbUsers(object):
         if user:
             p = '%s %s' % permit
             user.permits.append(p)
-            #session.commit()
+            session.commit()
             session.refesh(user)
             rlog(10, 'users', '%s permit %s added' % (userhost, p))
             return True
@@ -641,7 +672,7 @@ class DbUsers(object):
 
         if user:
             user.statuses.append(status.upper())
-            #session.commit()
+            session.commit()
             session.refresh(user)
             rlog(10, 'users', '%s status %s added' % (name, status))
             return True
@@ -666,7 +697,7 @@ class DbUsers(object):
             session.add(user)
 
         user.userhosts.append(userhost)
-        #session.commit()
+        session.commit()
         session.refresh(user)
         rlog(10, 'users', '%s (%s) added to userhosts' % (name, userhost))
         return True
@@ -686,7 +717,7 @@ class DbUsers(object):
 
         if user:
             user.email.append(email)
-            #session.commit()
+            session.commit()
             session.refresh(user)
             rlog(10, 'users', '%s email %s added' % (name, email))
             return True
@@ -707,7 +738,7 @@ class DbUsers(object):
         if user:
             perm = perm.upper()
             user.perms.append(perm)
-            #session.commit()
+            session.commit()
             session.refresh(user)
             rlog(10, 'users', '%s perm %s added' % (name, perm))
             return True
@@ -730,7 +761,7 @@ class DbUsers(object):
         if user:
             p = '%s %s' % (who, permit)
             user.permits.append(p)
-            #session.commit()
+            session.commit()
             session.refresh(user)
             rlog(10, 'users', '%s permit %s added' % (name, p))
             return True
@@ -752,7 +783,7 @@ class DbUsers(object):
 
         if user:
             user.statuses.append(status.upper())
-            #session.commit()
+            session.commit()
             session.refresh(user)
             rlog(10, 'users', '%s status %s added' % (name, status))
             return True
@@ -775,7 +806,7 @@ class DbUsers(object):
             for user in users:
                 user.perms.append(perm.upper())
                 session.refresh(user)
-                #session.commit()
+                session.commit()
 
     ### Delete functions
     @trans
@@ -794,7 +825,7 @@ class DbUsers(object):
         if user:
             if email in user.emails:
                 user.emails.remove(email)
-                #session.commit()
+                session.commit()
                 session.refresh(user)
                 return True
 
@@ -818,7 +849,7 @@ class DbUsers(object):
 
             if p in user.perms:
                 user.perms.remove(p)
-                #session.commit()
+                session.commit()
                 session.refresh(user)
                 return True
 
@@ -841,7 +872,7 @@ class DbUsers(object):
 
             if p in user.permits:
                 user.permits.remove(p)
-                #session.commit()
+                session.commit()
                 session.refresh(user)
                 return True
 
@@ -865,7 +896,7 @@ class DbUsers(object):
 
             if st in user.statuses:
                 user.statuses.remove(st)
-                #session.commit()
+                session.commit()
                 session.refresh(user)
                 return True
 
@@ -885,8 +916,8 @@ class DbUsers(object):
         user = byname(name, session)
 
         if user:
+            rlog(10, 'users', "deleting %s" % name)
             session.delete(user)
-            session.commit()
             return True
 
         return False
@@ -907,8 +938,8 @@ class DbUsers(object):
         if user:
             if userhost in user.userhosts:
                 user.userhosts.remove(userhost)
-                #session.commit()
                 session.refresh(user)
+                session.commit()
                 rlog(10, 'users', '%s userhost %s deleted' % (name, userhost))
                 return True
 
@@ -930,8 +961,8 @@ class DbUsers(object):
         if user:
             if email in user.email:
                 user.email.remove(email)
-                #session.commit()
                 session.refresh(user)
+                session.commit()
                 rlog(10, 'users', '%s email %s deleted' % (name, email))
                 return True
 
@@ -955,8 +986,8 @@ class DbUsers(object):
 
             if p in user.perms:
                 user.perms.remove(p)
-                #session.commit()
                 session.refresh(user)
+                session.commit()
                 rlog(10, 'users', '%s perm %s deleted' % (name, p))
                 return True
 
@@ -980,8 +1011,8 @@ class DbUsers(object):
 
             if p in user.permits:
                 user.permits.remove(p)
-                #session.commit()
                 session.refresh(user)
+                session.commit()
                 rlog(10, 'users', '%s permit %s deleted' % (name, p))
                 return True
 
@@ -1005,8 +1036,8 @@ class DbUsers(object):
 
             if st in user.statuses:
                 user.statuses.remove(status)
-                #session.commit()
                 session.refresh(user)
+                session.commit()
                 rlog(10, 'users', '%s status %s deleted' % (name, st))
                 return True
 
@@ -1028,8 +1059,8 @@ class DbUsers(object):
 
         if user:
             user.email = []
-            #session.commit()
             session.refresh(user)
+            session.commit()
             rlog(10, 'users', '%s emails deleted' % (name, ))
             return True
 
@@ -1055,8 +1086,8 @@ class DbUsers(object):
 
                 try:
                     user.perms.remove(perm)
-                    #session.commit()
                     session.refresh(user)
+                    session.commit()
 
                 except ValueError:
                     pass
@@ -1090,10 +1121,15 @@ class DbUsers(object):
             if not username:
                 if not self.merge('owner', unicode(userhost)):
                     self.add('owner', [unicode(userhost), ], ['USER', 'OPER'])
-
+            elif username != 'owner':
+                self.delete(username)
+                if not self.merge('owner', unicode(userhost)):
+                    self.add('owner', [unicode(userhost), ], ['USER', 'OPER'])
+               
 ## INIT SECTION
 
 # default to database
+
 if not config['nodb']:
     users = DbUsers()
 else:
