@@ -46,6 +46,9 @@ def whichmodule(depth=1):
             mod.append(i)
             if i == 'gozerbot' or i == 'gozerplugs':
                 break
+            if i == 'generic':
+                plugname = frame.f_back.f_back.f_code.co_filename
+                name = plugname.split(os.sep)[-1][:-3]
         modstr = '.'.join(mod[::-1]) + ':' + str(lineno)
     except AttributeError:
         modstr = None
